@@ -1,4 +1,4 @@
-use swc_common::{chain, SyntaxContext};
+use swc_common::chain;
 use swc_ecma_visit::VisitMut;
 
 use crate::{marks::Marks, option::MangleOptions};
@@ -8,13 +8,9 @@ mod preserver;
 mod private_name;
 mod real_impl;
 
-pub(crate) fn name_mangler(
-    options: MangleOptions,
-    marks: Marks,
-    top_level_ctxt: SyntaxContext,
-) -> impl VisitMut {
+pub(crate) fn name_mangler(options: MangleOptions, marks: Marks) -> impl VisitMut {
     chain!(
         self::private_name::private_name_mangler(options.keep_private_props),
-        self::real_impl::name_mangler(options, marks, top_level_ctxt)
+        self::real_impl::name_mangler(options, marks,)
     )
 }
